==> xlnl-3.3.4.tar.gz: xlnl-3.3.4/src/ver.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: ver.h,v 1.57 2008/09/15 07:15:52 bowkenken Exp $
***************************************************************/

#ifndef	VER_H
#define	VER_H

#define	STR_FILE_NAME_GAME	"lnl"

#define	STR_GAME_TITLE	"L&L - Labyrinths & Legends"
#define	STR_VER_GAME	VERSION

#define	STR_SINCE	"1993"
#define	STR_LATEST	"2008"
#define	STR_AUTHOR	"YOSHIMURA Tomohiko"

#define	STR_WEB	"http://lnl.sourceforge.jp/"
#define	STR_E_MAIL	"bowkenken@users.sourceforge.jp"

#define	STR_TITLE_1	"Created by"
#define	STR_HANDLE_1	"bowkenken"

#define	STR_TITLE_2	"Graphic Design"
#define	STR_HANDLE_2	"[RPG DOT], Whitecat, REFMAP"

#define	STR_TITLE_3	" "
#define	STR_HANDLE_3	"kokusi(yujyu), hiyo and URARA"

#define	STR_TITLE_4	"Photograph"
#define	STR_HANDLE_4	"Yoshinori Kamimura"

#define	STR_TITLE_5	"Music Production"
#define	STR_HANDLE_5	"Presence of Music"

#define	STR_TITLE_THANKS	"Special Thanks"
#define	STR_HANDLE_THANKS	"t-oikawa, TeaMiKL, nnn and you"

#define	STR_FMT_COPYRIGHT	\
		"\n" \
		"--------------------------------" \
		"--------------------------------\n" \
		"%s : version %s  \n" \
		"Copyright (c) %s-%s %s All rights reserved.\n" \
		"                                " \
		"                                \n" \
		"URL   : %-56s\n" \
		"E-mail: %-56s\n" \
		"                                " \
		"                                \n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"--------------------------------" \
		"--------------------------------\n" \
		""

#define	LS_STR_COPYRIGHT	\
		STR_GAME_TITLE, STR_VER_GAME, \
		STR_SINCE, STR_LATEST, STR_AUTHOR, \
		STR_WEB, \
		STR_E_MAIL, \
		STR_TITLE_1, STR_HANDLE_1, \
		STR_TITLE_2, STR_HANDLE_2, \
		STR_TITLE_3, STR_HANDLE_3, \
		STR_TITLE_4, STR_HANDLE_4, \
		STR_TITLE_5, STR_HANDLE_5, \
		STR_TITLE_THANKS, STR_HANDLE_THANKS

#endif	/* VER_H */

==> xlnl-3.4.3.tar.gz: xlnl-3.4.3/src/ver.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: ver.h,v 1.59 2009/01/04 00:24:52 bowkenken Exp $
***************************************************************/

#ifndef	VER_H
#define	VER_H

#define	STR_FILE_NAME_GAME	"lnl"

#define	STR_GAME_TITLE	"L&L - Labyrinths & Legends"
#define	STR_VER_GAME	VERSION

#define	STR_SINCE	"1993"
#define	STR_LATEST	"2009"
#define	STR_AUTHOR	"YOSHIMURA, Tomohiko"

#define	STR_WEB	"http://lnl.sourceforge.jp/"
#define	STR_E_MAIL	"bowkenken@users.sourceforge.jp"

#define	STR_TITLE_1	"Created by"
#define	STR_HANDLE_1	"bowkenken"

#define	STR_TITLE_2	"Graphic Design"
#define	STR_HANDLE_2	"[RPG DOT], Whitecat, REFMAP"

#define	STR_TITLE_3	" "
#define	STR_HANDLE_3	"kokusi(yujyu), hiyo and URARA"

#define	STR_TITLE_4	"Photograph"
#define	STR_HANDLE_4	"Yoshinori Kamimura"

#define	STR_TITLE_5	"Music Production"
#define	STR_HANDLE_5	"Presence of Music"

#define	STR_TITLE_THANKS	"Special Thanks"
#define	STR_HANDLE_THANKS	"t-oikawa, TeaMiKL, nnn and you"

#define	STR_FMT_COPYRIGHT	\
		"\n" \
		"--------------------------------" \
		"--------------------------------\n" \
		"%s : version %s  \n" \
		"Copyright (c) %s-%s %s All rights reserved.\n" \
		"                                " \
		"                                \n" \
		"URL   : %-56s\n" \
		"E-mail: %-56s\n" \
		"                                " \
		"                                \n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"%20s  %-42s\n" \
		"--------------------------------" \
		"--------------------------------\n" \
		""

#define	LS_STR_COPYRIGHT	\
		STR_GAME_TITLE, STR_VER_GAME, \
		STR_SINCE, STR_LATEST, STR_AUTHOR, \
		STR_WEB, \
		STR_E_MAIL, \
		STR_TITLE_1, STR_HANDLE_1, \
		STR_TITLE_2, STR_HANDLE_2, \
		STR_TITLE_3, STR_HANDLE_3, \
		STR_TITLE_4, STR_HANDLE_4, \
		STR_TITLE_5, STR_HANDLE_5, \
		STR_TITLE_THANKS, STR_HANDLE_THANKS

#endif	/* VER_H */
